@@ -269,7 +269,7 @@ async fn process_control(
                             );
                             break;
                         }
-                        if db.subscribe(topic, client.clone()).is_err() {
+                        if db.subscribe(topic, &client).is_err() {
                             res = RESPONSE_ERR;
                             break;
                         }
@@ -293,7 +293,7 @@ async fn process_control(
                 {
                     let mut db = dbm!();
                     for topic in topics {
-                        if db.unsubscribe(topic, client.clone()).is_err() {
+                        if db.unsubscribe(topic, &client).is_err() {
                             success = false;
                             break;
                         }
@@ -1278,8 +1278,8 @@ mod stats {
     use std::convert::Infallible;
     use std::net::SocketAddr;
 
-    const HTML_STATS: &str = include_str!("stats.html");
-    const JS_CHART_MIN: &str = include_str!("chart.min.js");
+    static HTML_STATS: &str = include_str!("stats.html");
+    static JS_CHART_MIN: &str = include_str!("chart.min.js");
 
     macro_rules! http_error {
         ($status: expr) => {
